## duskCrawler

duskCrawler is a Python program that crawls throught set horoscope url: https://www.astrology.com/horoscope/daily.html.

## Installation

Use the package manager [pip] or [poetry] to add this program to your enviroment

```bash
pip install duskCrawler
poetry add duskCrawler
```

## Requirements

This module requires the following packages:
lxml, pandas, pytest, requests

## Usage

```python
process_page("https://www.astrology.com/horoscope/daily.html")
```
After succesful program run, user gets prompted if they want the data saved to their computer.
If data is needed to be saved to users computer, program saves the data as a .csv file

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

## Example data

Start page: https://www.astrology.com/horoscope/daily.html

Article link: https://www.astrology.com/horoscope/daily/aries.html
December 20, 2023

An instinctive and impulsive energy flows through you this morning,
dear Aries, as the moon continues its journey through your sign.
Unfortunately, you may have trouble getting past stubborn behaviors as
Venus and Uranus face off, making it important that you don't get your
own way by clinging to tradition. A destructive element also comes
into play, and you'll want to avoid reacting hastily when confronted
with chaos or plot twists. Take a moment to acknowledge your basic
needs this evening when Chiron activates, offering healing and calm.
Inspiration strikes as the day comes to a close, and passionate Mars
triggers your solar ninth house.


Daily Food Horoscope

You'll feel uncharacteristically introverted today. Could a broken
heart be behind your blue mood? Doing something nice for yourself
could brighten your spirit. Soothe your soul with a thick piece of
cheesecake, a cup of mocha java and an upbeat movie.

Daily Home Horoscope

Buying your elderly father a computer is not a complete gift unless
you or someone else is willing to spend a few hours showing him the
basics. Patience is the key if you are doing it yourself.

Daily Dog Horoscope

Don't forget the surefire way to avoid a dogfight: make sure your bark
is worse than your bite. Keep it short and sweet, like the horn of a
semi. Once you get into the details, you're in trouble.

Daily Teen Horoscope

You can charm the birds out of the trees right now -- or your camp
counselor out of putting you on kitchen duty, if that's what you need
to do. Take advantage of your winsome wiles!

Daily Cat Horoscope

You need to let your human friends know what's important to you --
even though it might get pretty complicated! The day is just right for
showing your deepest feelings, though, so get to work.

Daily Bonus Horoscope

You can be forceful and tactful. Push a little harder, and you'll get
what you want.

Article link: https://www.astrology.com/horoscope/daily/taurus.html
December 20, 2023
...
...
...